<?php

namespace EventPortal\Domain\Email\Composers;

use EventPortal\Contracts\Event as EventContract;
use EventPortal\Domain\Component\Button;
use EventPortal\Domain\Email\Models\EventEmail;
use EventPortal\Enums\InertiaMethod;

class EmailSendComposer
{
    /** @var EventContract */
    protected $event;

    /** @var EventEmail */
    protected $email;

    /** @var array */
    public $buttons;

    /** @var array */
    public $content;

    public function __construct(EventContract $event, EventEmail $email)
    {
        $this->event = $event;
        $this->email = $email;
    }

    public function compose(): void
    {
        $totalDelegates = $this->event->delegates->count();
        $receivedDelegates = $this->event->notifications()
            ->where('key', $this->email->getNotificationKey())
            ->distinct('delegate_id')
            ->count();
        $numRemainingDelegates = max(0, $totalDelegates - $receivedDelegates);

        $this->buttons = [
            $this->getSendAllButton(),
        ];

        $this->content = [
            "Are you sure you want to send the {$this->email->type->getValue()} email?",
        ];

        if ($receivedDelegates < 1) {
            return;
        }

        $this->content[] = trans_choice('event.email.confirm_resend', $receivedDelegates);

        if ($numRemainingDelegates < 1) {
            return;
        }

        $this->buttons[] = $this->getSendOnlyToRemainingButton($numRemainingDelegates);
    }

    private function getSendAllButton(): Button
    {
        return Button::make("Send to all")
            ->method(InertiaMethod::POST())
            ->route('admin.email.send', [
                'event' => $this->event->id,
                'email' => $this->email->id,
            ]);
    }

    private function getSendOnlyToRemainingButton(int $numRemainingDelegates): Button
    {
        return Button::make(trans_choice('event.email.send_remaining', $numRemainingDelegates))
            ->method(InertiaMethod::POST())
            ->route('admin.email.send', [
                'event' => $this->event->id,
                'email' => $this->email->id,
                'only_remaining' => true,
            ]);
    }
}
