<?php

use EventPortal\Domain\Component\Button;
use EventPortal\Domain\Component\ButtonDropdown;
use EventPortal\Domain\Component\Column\TextColumn;
use EventPortal\Domain\Component\Filter\StatusFilter;
use EventPortal\Domain\Delegate\Models\Delegate;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Table\Facades\Table;
use EventPortal\Domain\Util\Status;
use EventPortal\Enums\InertiaMethod;
use Illuminate\Database\Eloquent\Builder;

Table::make('event-delegate.index')
    ->setFilters(function () {
        return [
            StatusFilter::make('Filter by status')
                ->name('status')
                ->forColumn('status')
                ->options(Status::make('eventDelegate')->forFilters()),
        ];
    })
    ->setColumns(function () {
        return [
            TextColumn::make('First name')->default()->searchable()->sortable(),
            TextColumn::make('Last name')->default()->searchable()->sortable(),
            TextColumn::make('Email')->default()->searchable()->sortable(),
            TextColumn::make('Status')->default(),
        ];
    })
    ->setRowAction(function (Event $event, Delegate $delegate) {
        return ButtonDropdown::make('Manage delegate')
            ->actions([
                Button::make('View')
                    ->method(InertiaMethod::VISIT())
                    ->route('admin.event.delegate.show', [
                        'event' => $event->id,
                        'delegate' => $delegate->id,
                    ]),
            ]);
    })
    ->addGlobalAction(function (Event $event) {
        return Button::make('Remove delegates from event')
            ->method(InertiaMethod::POST())
            ->route('admin.event.delegate.destroy', [
                'event' => $event->id,
            ]);
    });

Table::make('event-delegate.add')
    ->tapQuery(function (Builder $query) {
        return $query->joinRelationship('user');
    })
    ->setColumns(function () {
        return [
            TextColumn::make('ID')->name('identifier')->default()->searchable()->sortable(),
            TextColumn::make('First name')->default()->searchable()->sortable(),
            TextColumn::make('Last name')->default()->searchable()->sortable(),
            TextColumn::make('Email')->default()->searchable()->sortable(),
            TextColumn::make('Profession')->searchable()->sortable(),
        ];
    })
    ->addGlobalAction(function (Event $event) {
        return Button::make('Add delegates to event')
            ->method(InertiaMethod::POST())
            ->route('admin.event.delegate.store', [
                'event' => $event->id,
            ]);
    });
