<?php

namespace EventPortal\Tests\Unit\Util;

use EventPortal\Tests\TestCase;

class ToastTest extends TestCase
{
    /** @test */
    public function it_can_flash_success_toast(): void
    {
        toast()->success('Welcome Aboard');

        $this->assertSessionIsFlashed('Welcome Aboard', 'success');
    }

    /** @test */
    public function it_can_flash_success_toast_and_never_timeout(): void
    {
        toast()->neverTimeout()->success('Welcome Aboard');

        $this->assertSessionIsFlashed('Welcome Aboard', 'success', 0);
    }

    /** @test */
    public function it_can_flash_success_toast_and_set_timeout(): void
    {
        toast()->setTimeout(10)->success('Welcome Aboard');

        $this->assertSessionIsFlashed('Welcome Aboard', 'success', 10);
    }

    /** @test */
    public function it_can_flash_error_toast(): void
    {
        toast()->error('Oops something went wrong');

        $this->assertSessionIsFlashed('Oops something went wrong', 'error');
    }

    /** @test */
    public function it_can_flash_error_toast_and_never_timeout(): void
    {
        toast()->neverTimeout()->error('Oops something went wrong');

        $this->assertSessionIsFlashed('Oops something went wrong', 'error', 0);
    }

    /** @test */
    public function it_can_flash_error_toast_and_set_timeout(): void
    {
        toast()->setTimeout(10)->error('Oops something went wrong');

        $this->assertSessionIsFlashed('Oops something went wrong', 'error', 10);
    }

    protected function assertSessionIsFlashed(string $message, string $type, int $timeout = 5): void
    {
        $this->assertTrue(session()->has('toast'));
        $this->assertEquals(session('toast'), [
            'type' => $type,
            'message' => $message,
            'timeout' => $timeout * 1000,
        ]);
    }
}
